Struct ruma::KeyId [−][src]
pub struct KeyId<A, K> where
K: ?Sized, { /* fields omitted */ }Expand description
A key algorithm and key name delimited by a colon
Implementations
impl<A, K> KeyId<A, K> where
K: ?Sized, [src]
impl<A, K> KeyId<A, K> where
K: ?Sized, [src]Trait Implementations
impl<'de, A, K> Deserialize<'de> for KeyId<A, K> where
K: ?Sized, [src]
impl<'de, A, K> Deserialize<'de> for KeyId<A, K> where
K: ?Sized, [src]pub fn deserialize<D>(
deserializer: D
) -> Result<KeyId<A, K>, <D as Deserializer<'de>>::Error> where
D: Deserializer<'de>, [src]
pub fn deserialize<D>(
deserializer: D
) -> Result<KeyId<A, K>, <D as Deserializer<'de>>::Error> where
D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
impl<A, K> Ord for KeyId<A, K> where
K: ?Sized, [src]
impl<A, K> Ord for KeyId<A, K> where
K: ?Sized, [src]impl<A, K> PartialOrd<KeyId<A, K>> for KeyId<A, K> where
K: ?Sized, [src]
impl<A, K> PartialOrd<KeyId<A, K>> for KeyId<A, K> where
K: ?Sized, [src]pub fn partial_cmp(&self, other: &KeyId<A, K>) -> Option<Ordering>[src]
pub fn partial_cmp(&self, other: &KeyId<A, K>) -> Option<Ordering>[src]This method returns an ordering between self and other values if one exists. Read more
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl<A, K> Serialize for KeyId<A, K> where
K: ?Sized, [src]
impl<A, K> Serialize for KeyId<A, K> where
K: ?Sized, [src]pub fn serialize<S>(
&self,
serializer: S
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error> where
S: Serializer, [src]
pub fn serialize<S>(
&self,
serializer: S
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error> where
S: Serializer, [src]Serialize this value into the given Serde serializer. Read more
impl<A, K> Eq for KeyId<A, K> where
K: ?Sized, [src]
K: ?Sized,